macro_rules! debug_dbg {
($($val:expr),+ $(,)?) => { ... };
() => { ... };
}Expand description
It can be filtered by DEBUG env and can only log on debug mode
macro_rules! debug_dbg {
($($val:expr),+ $(,)?) => { ... };
() => { ... };
}It can be filtered by DEBUG env and can only log on debug mode