macro_rules! debug_log {
($($arg:tt)*) => { ... };
() => { ... };
}Expand description
Use it like println!(). Except it can be filtered by DEBUG env and can only log on debug mode
macro_rules! debug_log {
($($arg:tt)*) => { ... };
() => { ... };
}Use it like println!(). Except it can be filtered by DEBUG env and can only log on debug mode