macro_rules! group {
($($arg:tt)*) => { ... };
() => { ... };
}Expand description
Group the following logs until the guard is dropped
macro_rules! group {
($($arg:tt)*) => { ... };
() => { ... };
}Group the following logs until the guard is dropped